%define anolis_release 1
%global libmodulemd_version 2.3.0

%define __cmake_in_source_build 1

%global bash_completion %{_datadir}/bash-completion/completions/*

%bcond_without drpm

%bcond_without zchunk

%bcond_without libmodulemd

%bcond_with legacy_hashes

Summary:        Creates a common metadata repository
Name:           createrepo_c
Version:        1.1.2
Release:        %{anolis_release}%{?dist}
License:        GPL-2.0-or-later
URL:            https://github.com/rpm-software-management/createrepo_c
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
# https://github.com/rpm-software-management/createrepo_c/commit/424616d851d6fe58e89ae9b1b318853f8a899195
Patch0:         0001-Fix-a-file-descriptor-and-memory-leak-in-an-error-pa.patch

%global epoch_dep %{?epoch:%{epoch}:}

BuildRequires:  cmake
BuildRequires:  gcc
BuildRequires:  bzip2-devel
BuildRequires:  doxygen
BuildRequires:  glib2-devel >= 2.22.0
BuildRequires:  libcurl-devel
BuildRequires:  libxml2-devel
BuildRequires:  openssl-devel
BuildRequires:  rpm-devel >= 4.8.0-28
BuildRequires:  sqlite-devel >= 3.6.18
BuildRequires:  xz
BuildRequires:  xz-devel
BuildRequires:  zlib-devel
%if %{with zchunk}
BuildRequires:  pkgconfig(zck) >= 0.9.11
BuildRequires:  zchunk
%endif
%if %{with libmodulemd}
BuildRequires:  pkgconfig(modulemd-2.0) >= %{libmodulemd_version}
BuildRequires:  libmodulemd
Requires:       libmodulemd%{?_isa} >= %{libmodulemd_version}
%endif
Requires:       %{name}-libs = %{version}-%{release}
BuildRequires:  bash-completion
Requires: rpm >= 4.9.0
%if %{with drpm}
BuildRequires:  drpm-devel >= 0.4.0
%endif
BuildRequires:  pkgconfig(libzstd)

Obsoletes:      createrepo < 0.11.0
Provides:       createrepo = %{version}-%{release}

%description
C implementation of Createrepo.
A set of utilities (createrepo_c, mergerepo_c, modifyrepo_c)
for generating a common metadata repository from a directory of
rpm packages and maintaining it.

%package libs
Summary:    Library for repodata manipulation

%description libs
Libraries for applications using the createrepo_c library
for easy manipulation with a repodata.

%package devel
Summary:    Library for repodata manipulation
Requires:   %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
This package contains the createrepo_c C library and header files.
These development files are for easy manipulation with a repodata.

%package -n python3-%{name}
Summary:        Python 3 bindings for the createrepo_c library
%{?python_provide:%python_provide python3-%{name}}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-sphinx
Requires:       %{name}-libs = %{version}-%{release}

%description -n python3-%{name}
Python 3 bindings for the createrepo_c library.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1
%py3_shebang_fix examples/python
mkdir build-py3

%build
# Build createrepo_c with Pyhon 3
pushd build-py3
  %cmake .. \
      -DWITH_ZCHUNK=%{?with_zchunk:ON}%{!?with_zchunk:OFF} \
      -DWITH_LIBMODULEMD=%{?with_libmodulemd:ON}%{!?with_libmodulemd:OFF} \
      -DWITH_LEGACY_HASHES=%{?with_legacy_hashes:ON}%{!?with_legacy_hashes:OFF} \
      -DENABLE_DRPM=%{?with_drpm:ON}%{!?with_drpm:OFF} \
      -DWITH_SANITIZERS=OFF
  make %{?_smp_mflags} RPM_OPT_FLAGS="%{optflags}"
  # Build C documentation
  make doc-c
popd

%check
# Run Python 3 tests
pushd build-py3
  # Compile C tests
  make tests

  # Run Python 3 tests
  make ARGS="-V" test
popd

%install
pushd build-py3
  # Install createrepo_c with Python 3
  make install DESTDIR=%{buildroot}
popd

ln -sr %{buildroot}%{_bindir}/createrepo_c %{buildroot}%{_bindir}/createrepo
ln -sr %{buildroot}%{_bindir}/mergerepo_c %{buildroot}%{_bindir}/mergerepo
ln -sr %{buildroot}%{_bindir}/modifyrepo_c %{buildroot}%{_bindir}/modifyrepo
%ldconfig_scriptlets libs

%generate_compatibility_deps

%files
%doc README.md
%{_mandir}/man8/createrepo_c.8*
%{_mandir}/man8/mergerepo_c.8*
%{_mandir}/man8/modifyrepo_c.8*
%{_mandir}/man8/sqliterepo_c.8*
%{bash_completion}
%{_bindir}/createrepo_c
%{abidir}/%{name}-option.list
%{_bindir}/mergerepo_c
%{abidir}/mergerepo_c-option.list
%{_bindir}/modifyrepo_c
%{abidir}/modifyrepo_c-option.list
%{_bindir}/sqliterepo_c
%{abidir}/sqliterepo_c-option.list

%{_bindir}/createrepo
%{_bindir}/mergerepo
%{_bindir}/modifyrepo

%files libs
%license COPYING
%dir %{abidir}
%{_libdir}/lib%{name}.so.*
%{abidir}/lib%{name}.dump

%files devel
%doc build-py3/doc/html
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/

%files -n python3-%{name}
%doc examples/python/*
%{python3_sitearch}/%{name}/
%{abidir}/_%{name}.dump
%{python3_sitearch}/%{name}-%{version}-py%{python3_version}.egg-info

%files doc
%doc README.md AUTHORS

%changelog
* Fri Feb 28 2025 Zhao Hang <wb-zh951434@alibaba-inc.com> - 1.1.2-1
- Update to 1.1.2-1 from 0.20.1-2
- Convert license to SPDX
- Fix a file descriptor and a memory leak in an error path of cr_detect_compression()
  [Patches cherry-pick from c10s. Original changelog:
   Fix a file descriptor and a memory leak in an error path of cr_detect_compression()]

* Mon Mar 11 2024 Bo Ren <rb01097748@alibaba-inc.com> - 0.20.1-2
- Rebuild with python3.11
- Add BuildRequires python3-setuptools

* Mon Feb 13 2023 yuanhui <yuanhui@linux.alibaba.com> - 0.20.1-1
- add doc package and abi files

* Mon Apr 11 2022 Zhongling He <zhonglingh@linux.alibaba.com> 0.20.0-1
- Init package from upstream v0.20.0
